@@ -54,14 +54,17 @@ class Payload(Messages, frozen=True):
         return self.model_copy(update=dict(attachments=attachments))
 
     def __repr__(self):
+        return self.show_pretty()
+
+    def show_pretty(self, detailed: bool=False):
         total_size = sum(len(msg.content) for msg in self.messages)
         parts = [
             f"messages: {len(self.messages)}",
-            f"total size: {total_size}",
+            f"total size: {total_size}" if detailed else None,
             self.attachments and "has attachments",
         ]
         payload_pretty = ", ".join(filter(None, parts))
-        return f"Payload({payload_pretty})"
+        return f"Payload({payload_pretty})"        
 
     @staticmethod
     def create(user_text: str, resource_id: ResourceId = "") -> "Payload":
